@@ -1,5 +1,6 @@
 import ast
 import re
+
 #import sys
 
 fix_assign = re.compile(r'\.(\[[^\]]*\])')
@@ -138,6 +139,23 @@ class myvisitnode(ast.NodeVisitor):
                 self.targets[the_name] = 1
                 the_name = re.sub(r'\.[^\.]+$', '', the_name)
             self.targets[the_name] = 1
+    def visit_GeneratorExp(self, node):
+        for comp in node.generators:
+            if isinstance(comp.target, ast.Name):
+                self.targets[comp.target.id] = 1
+            elif isinstance(comp.target, ast.Tuple):
+                for subtarget in comp.target.elts:
+                    if isinstance(subtarget, ast.Name):
+                        self.targets[subtarget.id] = 1
+        self.generic_visit(node)
+    def visit_Lambda(self, node):
+        for arg in node.args.posonlyargs:
+            self.targets[arg.arg] = 1
+        for arg in node.args.args:
+            self.targets[arg.arg] = 1
+        for arg in node.args.kwonlyargs:
+            self.targets[arg.arg] = 1
+        self.generic_visit(node)
     def visit_ListComp(self, node):
         for comp in node.generators:
             if isinstance(comp.target, ast.Name):
@@ -147,6 +165,24 @@ class myvisitnode(ast.NodeVisitor):
                     if isinstance(subtarget, ast.Name):
                         self.targets[subtarget.id] = 1
         self.generic_visit(node)
+    def visit_DictComp(self, node):
+        for comp in node.generators:
+            if isinstance(comp.target, ast.Name):
+                self.targets[comp.target.id] = 1
+            elif isinstance(comp.target, ast.Tuple):
+                for subtarget in comp.target.elts:
+                    if isinstance(subtarget, ast.Name):
+                        self.targets[subtarget.id] = 1
+        self.generic_visit(node)
+    def visit_SetComp(self, node):
+        for comp in node.generators:
+            if isinstance(comp.target, ast.Name):
+                self.targets[comp.target.id] = 1
+            elif isinstance(comp.target, ast.Tuple):
+                for subtarget in comp.target.elts:
+                    if isinstance(subtarget, ast.Name):
+                        self.targets[subtarget.id] = 1
+        self.generic_visit(node)
     def visit_For(self, node):
         if isinstance(node.target, ast.Name):
             self.targets[node.target.id] = 1
